@@ -1485,65 +1485,65 @@ class ProfileStats:
             file=file,
         )
 
-        from pytensor import scalar as aes
+        from pytensor import scalar as ps
         from pytensor.tensor.elemwise import Elemwise
         from pytensor.tensor.math import Dot
 
         scalar_op_amdlibm_no_speed_up = [
-            aes.LT,
-            aes.GT,
-            aes.LE,
-            aes.GE,
-            aes.EQ,
-            aes.NEQ,
-            aes.InRange,
-            aes.Switch,
-            aes.OR,
-            aes.XOR,
-            aes.AND,
-            aes.Invert,
-            aes.ScalarMaximum,
-            aes.ScalarMinimum,
-            aes.Add,
-            aes.Mul,
-            aes.Sub,
-            aes.TrueDiv,
-            aes.IntDiv,
-            aes.Clip,
-            aes.Second,
-            aes.Identity,
-            aes.Cast,
-            aes.Sign,
-            aes.Neg,
-            aes.Reciprocal,
-            aes.Sqr,
+            ps.LT,
+            ps.GT,
+            ps.LE,
+            ps.GE,
+            ps.EQ,
+            ps.NEQ,
+            ps.InRange,
+            ps.Switch,
+            ps.OR,
+            ps.XOR,
+            ps.AND,
+            ps.Invert,
+            ps.ScalarMaximum,
+            ps.ScalarMinimum,
+            ps.Add,
+            ps.Mul,
+            ps.Sub,
+            ps.TrueDiv,
+            ps.IntDiv,
+            ps.Clip,
+            ps.Second,
+            ps.Identity,
+            ps.Cast,
+            ps.Sign,
+            ps.Neg,
+            ps.Reciprocal,
+            ps.Sqr,
         ]
         scalar_op_amdlibm_speed_up = [
-            aes.Mod,
-            aes.Pow,
-            aes.Ceil,
-            aes.Floor,
-            aes.RoundHalfToEven,
-            aes.RoundHalfAwayFromZero,
-            aes.Log,
-            aes.Log2,
-            aes.Log10,
-            aes.Log1p,
-            aes.Exp,
-            aes.Sqrt,
-            aes.Abs,
-            aes.Cos,
-            aes.Sin,
-            aes.Tan,
-            aes.Tanh,
-            aes.Cosh,
-            aes.Sinh,
-            aes.Sigmoid,
-            aes.Softplus,
+            ps.Mod,
+            ps.Pow,
+            ps.Ceil,
+            ps.Floor,
+            ps.RoundHalfToEven,
+            ps.RoundHalfAwayFromZero,
+            ps.Log,
+            ps.Log2,
+            ps.Log10,
+            ps.Log1p,
+            ps.Exp,
+            ps.Sqrt,
+            ps.Abs,
+            ps.Cos,
+            ps.Sin,
+            ps.Tan,
+            ps.Tanh,
+            ps.Cosh,
+            ps.Sinh,
+            ps.Sigmoid,
+            ps.Softplus,
         ]
 
         def get_scalar_ops(s):
-            if isinstance(s, aes.Composite):
+            if isinstance(s, ps.Composite):
                 l = []
                 for node in s.fgraph.toposort():
                     l += get_scalar_ops(node.op)
@@ -1552,7 +1552,7 @@ class ProfileStats:
                 return [s]
 
         def list_scalar_op(op):
-            if isinstance(op.scalar_op, aes.Composite):
+            if isinstance(op.scalar_op, ps.Composite):
                 return get_scalar_ops(op.scalar_op)
             else:
                 return [op.scalar_op]
@@ -1579,7 +1579,7 @@ class ProfileStats:
                 return False
             else:
                 l = list_scalar_op(op)
-                return any(s_op.__class__ in [aes.Exp] for s_op in l)
+                return any(s_op.__class__ in [ps.Exp] for s_op in l)
 
         printed_tip = False
         # tip 1
