@@ -1013,32 +1013,21 @@ def and_(a, b):
     """bitwise a & b"""
 
 
-bitwise_and = and_  # numpy name for it
-
-
 @scalar_elemwise
 def or_(a, b):
     """bitwise a | b"""
 
 
-bitwise_or = or_  # numpy name for it
-
-
 @scalar_elemwise
 def xor(a, b):
     """bitwise a ^ b"""
 
 
-bitwise_xor = xor  # numpy name for it
-
-
 @scalar_elemwise
 def invert(a):
     """bitwise ~a"""
 
 
-bitwise_not = invert  # numpy alias for it
-
 ##########################
 # Math
 ##########################
@@ -1167,10 +1156,6 @@ def sqr(a):
     """square of a"""
 
 
-# alias to sqr, included to maintain similarity with numpy interface
-square = sqr
-
-
 def cov(m, y=None, rowvar=True, bias=False, ddof=None, fweights=None, aweights=None):
     """Calculate the covariance matrix.
 
@@ -2956,6 +2941,21 @@ def vectorize_node_to_matmul(op, node, batched_x, batched_y):
         return vectorize_node_fallback(op, node, batched_x, batched_y)
 
 
+# NumPy logical aliases
+square = sqr
+
+bitwise_and = and_
+bitwise_or = or_
+bitwise_xor = xor
+bitwise_not = invert
+
+greater = gt
+greater_equal = ge
+less = lt
+less_equal = le
+equal = eq
+not_equal = neq
+
 __all__ = [
     "max_and_argmax",
     "max",
@@ -2966,11 +2966,17 @@ __all__ = [
     "smallest",
     "largest",
     "lt",
+    "less",
     "gt",
+    "greater",
     "le",
+    "less_equal",
     "ge",
+    "greater_equal",
     "eq",
+    "equal",
     "neq",
+    "not_equal",
     "isnan",
     "isinf",
     "allclose",
