@@ -16,7 +16,7 @@ from pytensor.link.c.params_type import ParamsType
 from pytensor.misc.safe_asarray import _asarray
 from pytensor.scalar import int32
 from pytensor.tensor import _get_vector_length, as_tensor_variable
-from pytensor.tensor import basic as at
+from pytensor.tensor import basic as ptb
 from pytensor.tensor import get_vector_length
 from pytensor.tensor.exceptions import NotScalarConstantError
 from pytensor.tensor.type import DenseTensorType, TensorType, int_dtypes, tensor
@@ -68,7 +68,7 @@ class Shape(COp):
 
     def make_node(self, x):
         if not isinstance(x, Variable):
-            x = at.as_tensor_variable(x)
+            x = ptb.as_tensor_variable(x)
 
         if isinstance(x.type, TensorType):
             out_var = TensorType("int64", (x.type.ndim,))()
@@ -146,7 +146,7 @@ _shape = Shape()
 def shape(x: Union[np.ndarray, Number, Variable]) -> Variable:
     """Return the shape of `x`."""
     if not isinstance(x, Variable):
-        x = at.as_tensor_variable(x)  # type: ignore
+        x = ptb.as_tensor_variable(x)  # type: ignore
 
     return cast(Variable, _shape(x))
 
@@ -411,12 +411,12 @@ class SpecifyShape(COp):
     def make_node(self, x, *shape):
         from pytensor.tensor.basic import get_underlying_scalar_constant_value
 
-        x = at.as_tensor_variable(x)
+        x = ptb.as_tensor_variable(x)
 
         shape = tuple(
             NoneConst
             if (s is None or NoneConst.equals(s))
-            else at.as_tensor_variable(s, ndim=0)
+            else ptb.as_tensor_variable(s, ndim=0)
             for s in shape
         )
 
@@ -469,7 +469,7 @@ class SpecifyShape(COp):
         for dim in range(node.inputs[0].type.ndim):
             s = shape[dim]
             try:
-                s = at.get_underlying_scalar_constant_value(s)
+                s = ptb.get_underlying_scalar_constant_value(s)
                 # We assume that `None` shapes are always retrieved by
                 # `get_underlying_scalar_constant_value`, and only in that case do we default to
                 # the shape of the input variable
@@ -477,7 +477,7 @@ class SpecifyShape(COp):
                     s = xshape[dim]
             except NotScalarConstantError:
                 pass
-            new_shape.append(at.as_tensor_variable(s))
+            new_shape.append(ptb.as_tensor_variable(s))
 
         assert len(new_shape) == len(xshape)
         return [new_shape]
@@ -570,7 +570,7 @@ def specify_shape(
     # If shape is a symbolic 1d vector of fixed length, we separate the items into a
     # tuple with one entry per shape dimension
     if len(shape) == 1 and shape[0] is not None:
-        shape_vector = at.as_tensor_variable(shape[0])
+        shape_vector = ptb.as_tensor_variable(shape[0])
         if shape_vector.ndim == 1:
             try:
                 shape = tuple(shape_vector)
@@ -579,7 +579,7 @@ def specify_shape(
 
     # If the specified shape is already encoded in the input static shape, do nothing
     # This ignores PyTensor constants in shape
-    x = at.as_tensor_variable(x)  # type: ignore
+    x = ptb.as_tensor_variable(x)  # type: ignore
     new_shape_info = any(
         s != xts for (s, xts) in zip(shape, x.type.shape) if s is not None
     )
@@ -593,7 +593,7 @@ def specify_shape(
 @_get_vector_length.register(SpecifyShape)  # type: ignore
 def _get_vector_length_SpecifyShape(op: Op, var: TensorVariable) -> int:
     try:
-        return int(at.get_underlying_scalar_constant_value(var.owner.inputs[1]).item())
+        return int(ptb.get_underlying_scalar_constant_value(var.owner.inputs[1]).item())
     except NotScalarConstantError:
         raise ValueError(f"Length of {var} cannot be determined")
 
@@ -649,9 +649,9 @@ class Reshape(COp):
         return f"{self.__class__.__name__}{{{self.ndim}}}"
 
     def make_node(self, x, shp):
-        x = at.as_tensor_variable(x)
+        x = ptb.as_tensor_variable(x)
         shp_orig = shp
-        shp = at.as_tensor_variable(shp, ndim=1)
+        shp = ptb.as_tensor_variable(shp, ndim=1)
         if not (
             shp.dtype in int_dtypes
             or (isinstance(shp, TensorConstant) and shp.data.size == 0)
@@ -672,9 +672,9 @@ class Reshape(COp):
                 shp_list = [shp_orig]
             for index in range(self.ndim):
                 y = shp_list[index]
-                y = at.as_tensor_variable(y)
+                y = ptb.as_tensor_variable(y)
                 try:
-                    s_val = at.get_underlying_scalar_constant_value(y).item()
+                    s_val = ptb.get_underlying_scalar_constant_value(y).item()
                     if s_val >= 0:
                         out_shape[index] = s_val
                 except NotScalarConstantError:
@@ -773,7 +773,7 @@ class Reshape(COp):
             return [
                 tuple(
                     [
-                        at.switch(eq(requ[i], -1), rest_size, requ[i])
+                        ptb.switch(eq(requ[i], -1), rest_size, requ[i])
                         for i in range(self.ndim)
                     ]
                 )
@@ -836,7 +836,7 @@ def _vectorize_reshape(op, node, x, shape):
 
 def reshape(x, newshape, ndim=None):
     if ndim is None:
-        newshape = at.as_tensor_variable(newshape)
+        newshape = ptb.as_tensor_variable(newshape)
         if newshape.type.ndim != 1:
             raise TypeError(
                 "New shape in reshape must be a vector or a list/tuple of"
@@ -867,7 +867,7 @@ def shape_padleft(t, n_ones=1):
     Dimshuffle
 
     """
-    _t = at.as_tensor_variable(t)
+    _t = ptb.as_tensor_variable(t)
     if n_ones == 0:
         return _t
     pattern = ["x"] * n_ones + list(range(_t.type.ndim))
@@ -884,7 +884,7 @@ def shape_padright(t, n_ones=1):
     Dimshuffle
 
     """
-    _t = at.as_tensor_variable(t)
+    _t = ptb.as_tensor_variable(t)
     if n_ones == 0:
         return _t
     pattern = list(range(_t.type.ndim)) + ["x"] * n_ones
@@ -913,7 +913,7 @@ def shape_padaxis(t, axis):
     Dimshuffle
 
     """
-    _t = at.as_tensor_variable(t)
+    _t = ptb.as_tensor_variable(t)
 
     ndim = _t.ndim + 1
     if not -ndim <= axis < ndim:
