@@ -7,7 +7,7 @@ from typing import Optional, TypeVar
 
 import numpy as np
 
-from pytensor import tensor as at
+from pytensor import tensor as pt
 from pytensor.configdefaults import config
 from pytensor.graph.basic import Constant, OptionalApplyType, Variable
 from pytensor.graph.utils import MetaType
@@ -24,10 +24,10 @@ _TensorTypeType = TypeVar("_TensorTypeType", bound=TensorType)
 
 class _tensor_py_operators:
     def __abs__(self):
-        return at.math.abs(self)
+        return pt.math.abs(self)
 
     def __neg__(self):
-        return at.math.neg(self)
+        return pt.math.neg(self)
 
     # These won't work because Python requires an int return value
     # def __int__(self): return convert_to_int32(self)
@@ -37,22 +37,22 @@ class _tensor_py_operators:
     _is_nonzero = True
 
     def __lt__(self, other):
-        rval = at.math.lt(self, other)
+        rval = pt.math.lt(self, other)
         rval._is_nonzero = False
         return rval
 
     def __le__(self, other):
-        rval = at.math.le(self, other)
+        rval = pt.math.le(self, other)
         rval._is_nonzero = False
         return rval
 
     def __gt__(self, other):
-        rval = at.math.gt(self, other)
+        rval = pt.math.gt(self, other)
         rval._is_nonzero = False
         return rval
 
     def __ge__(self, other):
-        rval = at.math.ge(self, other)
+        rval = pt.math.ge(self, other)
         rval._is_nonzero = False
         return rval
 
@@ -72,25 +72,25 @@ class _tensor_py_operators:
             raise TypeError("Variables do not support boolean operations.")
 
     def __invert__(self):
-        return at.math.invert(self)
+        return pt.math.invert(self)
 
     def __and__(self, other):
-        return at.math.and_(self, other)
+        return pt.math.and_(self, other)
 
     def __or__(self, other):
-        return at.math.or_(self, other)
+        return pt.math.or_(self, other)
 
     def __xor__(self, other):
-        return at.math.xor(self, other)
+        return pt.math.xor(self, other)
 
     def __rand__(self, other):
-        return at.math.and_(other, self)
+        return pt.math.and_(other, self)
 
     def __ror__(self, other):
-        return at.math.or_(other, self)
+        return pt.math.or_(other, self)
 
     def __rxor__(self, other):
-        return at.math.xor(other, self)
+        return pt.math.xor(other, self)
 
     # def __iand__(self, other):
     #    return _and_inplace(self, other)
@@ -103,7 +103,7 @@ class _tensor_py_operators:
 
     def __add__(self, other):
         try:
-            return at.math.add(self, other)
+            return pt.math.add(self, other)
         # We should catch the minimum number of exception here.
         # Otherwise this will convert error when PyTensor flags
         # compute_test_value is used
@@ -122,7 +122,7 @@ class _tensor_py_operators:
         # See explanation in __add__ for the error caught
         # and the return value in that case
         try:
-            return at.math.sub(self, other)
+            return pt.math.sub(self, other)
         except (NotImplementedError, TypeError):
             return NotImplemented
 
@@ -130,7 +130,7 @@ class _tensor_py_operators:
         # See explanation in __add__ for the error caught
         # and the return value in that case
         try:
-            return at.math.mul(self, other)
+            return pt.math.mul(self, other)
         except (NotImplementedError, TypeError):
             return NotImplemented
 
@@ -138,7 +138,7 @@ class _tensor_py_operators:
         # See explanation in __add__ for the error caught
         # and the return value in that case
         try:
-            return at.math.div_proxy(self, other)
+            return pt.math.div_proxy(self, other)
         except IntegerDivisionError:
             # This is to raise the exception that occurs when trying to divide
             # two integer arrays (currently forbidden).
@@ -150,7 +150,7 @@ class _tensor_py_operators:
         # See explanation in __add__ for the error caught
         # and the return value in that case
         try:
-            return at.math.pow(self, other)
+            return pt.math.pow(self, other)
         except (NotImplementedError, TypeError):
             return NotImplemented
 
@@ -158,7 +158,7 @@ class _tensor_py_operators:
         # See explanation in __add__ for the error caught
         # and the return value in that case
         try:
-            return at.math.mod_check(self, other)
+            return pt.math.mod_check(self, other)
         except ComplexError:
             # This is to raise the exception that occurs when trying to compute
             # x % y with either x or y a complex number.
@@ -167,19 +167,19 @@ class _tensor_py_operators:
             return NotImplemented
 
     def __divmod__(self, other):
-        return at.math.divmod(self, other)
+        return pt.math.divmod(self, other)
 
     def __truediv__(self, other):
-        return at.math.true_div(self, other)
+        return pt.math.true_div(self, other)
 
     def __floordiv__(self, other):
-        return at.math.floor_div(self, other)
+        return pt.math.floor_div(self, other)
 
     def __rtruediv__(self, other):
-        return at.math.true_div(other, self)
+        return pt.math.true_div(other, self)
 
     def __rfloordiv__(self, other):
-        return at.math.floor_div(other, self)
+        return pt.math.floor_div(other, self)
 
     # Do not use these; in-place `Op`s should be inserted by optimizations
     # only!
@@ -198,39 +198,39 @@ class _tensor_py_operators:
     #    return _pow_inplace(self, other)
 
     def __radd__(self, other):
-        return at.math.add(other, self)
+        return pt.math.add(other, self)
 
     def __rsub__(self, other):
-        return at.math.sub(other, self)
+        return pt.math.sub(other, self)
 
     def __rmul__(self, other):
-        return at.math.mul(other, self)
+        return pt.math.mul(other, self)
 
     def __rdiv__(self, other):
-        return at.math.div_proxy(other, self)
+        return pt.math.div_proxy(other, self)
 
     def __rmod__(self, other):
-        return at.math.mod(other, self)
+        return pt.math.mod(other, self)
 
     def __rdivmod__(self, other):
-        return at.math.divmod(other, self)
+        return pt.math.divmod(other, self)
 
     def __rpow__(self, other):
-        return at.math.pow(other, self)
+        return pt.math.pow(other, self)
 
     def __ceil__(self):
-        return at.math.ceil(self)
+        return pt.math.ceil(self)
 
     def __floor__(self):
-        return at.math.floor(self)
+        return pt.math.floor(self)
 
     def __trunc__(self):
-        return at.math.trunc(self)
+        return pt.math.trunc(self)
 
     # NumPy-like transpose property
     @property
     def T(self):
-        return at.basic.transpose(self)
+        return pt.basic.transpose(self)
 
     def transpose(self, *axes):
         """Transpose this array.
@@ -246,33 +246,33 @@ class _tensor_py_operators:
 
         """
         if len(axes) == 0:
-            return at.basic.transpose(self)
+            return pt.basic.transpose(self)
         try:
             iter(axes[0])
             iterable = True
         except TypeError:
             iterable = False
         if len(axes) == 1 and iterable:
-            return at.basic.transpose(self, axes[0])
+            return pt.basic.transpose(self, axes[0])
         else:
-            return at.basic.transpose(self, axes)
+            return pt.basic.transpose(self, axes)
 
     @property
     def shape(self):
-        return at.shape(self)
+        return pt.shape(self)
 
     @property
     def size(self):
         if self.ndim == 1:
             return self.shape[0]
         else:
-            return at.math.prod(self.shape)
+            return pt.math.prod(self.shape)
 
     def any(self, axis=None, keepdims=False):
-        return at.math.any(self, axis=axis, keepdims=keepdims)
+        return pt.math.any(self, axis=axis, keepdims=keepdims)
 
     def all(self, axis=None, keepdims=False):
-        return at.math.all(self, axis=axis, keepdims=keepdims)
+        return pt.math.all(self, axis=axis, keepdims=keepdims)
 
     # Old note: "We can't implement this because Python requests that this
     # function returns an integer."
@@ -307,7 +307,7 @@ class _tensor_py_operators:
                     "Expected ndim to be an integer, is " + str(type(ndim))
                 )
 
-        return at.reshape(self, shape, ndim=ndim)
+        return pt.reshape(self, shape, ndim=ndim)
 
     def dimshuffle(self, *pattern):
         """
@@ -340,17 +340,17 @@ class _tensor_py_operators:
         """
         if (len(pattern) == 1) and (isinstance(pattern[0], (list, tuple))):
             pattern = pattern[0]
-        op = at.elemwise.DimShuffle(list(self.type.broadcastable), pattern)
+        op = pt.elemwise.DimShuffle(list(self.type.broadcastable), pattern)
         return op(self)
 
     def flatten(self, ndim=1):
-        return at.basic.flatten(self, ndim)
+        return pt.basic.flatten(self, ndim)
 
     def ravel(self):
-        return at.basic.flatten(self)
+        return pt.basic.flatten(self)
 
     def diagonal(self, offset=0, axis1=0, axis2=1):
-        return at.basic.diagonal(self, offset, axis1, axis2)
+        return pt.basic.diagonal(self, offset, axis1, axis2)
 
     def transfer(self, target):
         """Transfer this this array's data to another device.
@@ -363,85 +363,85 @@ class _tensor_py_operators:
         target : str
             The desired location of the output variable
         """
-        return at.basic.transfer(self, target)
+        return pt.basic.transfer(self, target)
 
     def arccos(self):
-        return at.math.arccos(self)
+        return pt.math.arccos(self)
 
     def arccosh(self):
-        return at.math.arccosh(self)
+        return pt.math.arccosh(self)
 
     def arcsin(self):
-        return at.math.arcsin(self)
+        return pt.math.arcsin(self)
 
     def arcsinh(self):
-        return at.math.arcsinh(self)
+        return pt.math.arcsinh(self)
 
     def arctan(self):
-        return at.math.arctan(self)
+        return pt.math.arctan(self)
 
     def arctanh(self):
-        return at.math.arctanh(self)
+        return pt.math.arctanh(self)
 
     def ceil(self):
-        return at.math.ceil(self)
+        return pt.math.ceil(self)
 
     def cos(self):
-        return at.math.cos(self)
+        return pt.math.cos(self)
 
     def cosh(self):
-        return at.math.cosh(self)
+        return pt.math.cosh(self)
 
     def deg2rad(self):
-        return at.math.deg2rad(self)
+        return pt.math.deg2rad(self)
 
     def exp(self):
-        return at.math.exp(self)
+        return pt.math.exp(self)
 
     def exp2(self):
-        return at.math.exp2(self)
+        return pt.math.exp2(self)
 
     def expm1(self):
-        return at.math.expm1(self)
+        return pt.math.expm1(self)
 
     def floor(self):
-        return at.math.floor(self)
+        return pt.math.floor(self)
 
     def log(self):
-        return at.math.log(self)
+        return pt.math.log(self)
 
     def log10(self):
-        return at.math.log10(self)
+        return pt.math.log10(self)
 
     def log1p(self):
-        return at.math.log1p(self)
+        return pt.math.log1p(self)
 
     def log2(self):
-        return at.math.log2(self)
+        return pt.math.log2(self)
 
     def rad2deg(self):
-        return at.math.rad2deg(self)
+        return pt.math.rad2deg(self)
 
     def sin(self):
-        return at.math.sin(self)
+        return pt.math.sin(self)
 
     def sinh(self):
-        return at.math.sinh(self)
+        return pt.math.sinh(self)
 
     def sqrt(self):
-        return at.math.sqrt(self)
+        return pt.math.sqrt(self)
 
     def tan(self):
-        return at.math.tan(self)
+        return pt.math.tan(self)
 
     def tanh(self):
-        return at.math.tanh(self)
+        return pt.math.tanh(self)
 
     def trunc(self):
-        return at.math.trunc(self)
+        return pt.math.trunc(self)
 
     def astype(self, dtype):
-        return at.basic.cast(self, dtype)
+        return pt.basic.cast(self, dtype)
 
     def __getitem__(self, args):
         def includes_bool(args_el):
@@ -502,9 +502,9 @@ class _tensor_py_operators:
         if len(ellipses) > 1:
             raise IndexError("an index can only have a single Ellipsis (`...`)")
         elif len(ellipses) == 1:
-            ellipsis_at = ellipses[0]
+            ellipsis_pt = ellipses[0]
             args = list(args)
-            args[ellipsis_at : ellipsis_at + 1] = [slice(None)] * (
+            args[ellipsis_pt : ellipsis_pt + 1] = [slice(None)] * (
                 self.ndim - index_dim_count
             )
 
@@ -518,7 +518,7 @@ class _tensor_py_operators:
         # Convert python literals to pytensor constants
         args = tuple(
             [
-                at.subtensor.as_index_constant(
+                pt.subtensor.as_index_constant(
                     np.array(inp, dtype=np.uint8) if is_empty_array(inp) else inp
                 )
                 for inp in args
@@ -537,7 +537,7 @@ class _tensor_py_operators:
 
             if arg is not np.newaxis and arg is not NoneConst:
                 try:
-                    at.subtensor.index_vars_to_types(arg)
+                    pt.subtensor.index_vars_to_types(arg)
                 except AdvancedIndexingError:
                     if advanced:
                         break
@@ -545,7 +545,7 @@ class _tensor_py_operators:
                         advanced = True
 
         if advanced:
-            return at.subtensor.advanced_subtensor(self, *args)
+            return pt.subtensor.advanced_subtensor(self, *args)
         else:
             if np.newaxis in args or NoneConst in args:
                 # `np.newaxis` (i.e. `None`) in NumPy indexing mean "add a new
@@ -587,9 +587,9 @@ class _tensor_py_operators:
                 else:
                     return view.__getitem__(tuple(new_args))
             else:
-                return at.subtensor.Subtensor(args)(
+                return pt.subtensor.Subtensor(args)(
                     self,
-                    *at.subtensor.get_slice_elements(
+                    *pt.subtensor.get_slice_elements(
                         args, lambda entry: isinstance(entry, Variable)
                     ),
                 )
@@ -600,20 +600,20 @@ class _tensor_py_operators:
         )
 
     def take(self, indices, axis=None, mode="raise"):
-        return at.subtensor.take(self, indices, axis, mode)
+        return pt.subtensor.take(self, indices, axis, mode)
 
     def copy(self, name=None):
         """Return a symbolic copy and optionally assign a name.
 
         Does not copy the tags.
         """
-        copied_variable = at.basic.tensor_copy(self)
+        copied_variable = pt.basic.tensor_copy(self)
         copied_variable.name = name
         return copied_variable
 
     def __iter__(self):
         try:
-            for i in range(at.basic.get_vector_length(self)):
+            for i in range(pt.basic.get_vector_length(self)):
                 yield self[i]
         except TypeError:
             # This prevents accidental iteration via sum(self)
@@ -646,28 +646,28 @@ class _tensor_py_operators:
         return self.type.dtype
 
     def __dot__(left, right):
-        return at.math.dense_dot(left, right)
+        return pt.math.dense_dot(left, right)
 
     def __rdot__(right, left):
-        return at.math.dense_dot(left, right)
+        return pt.math.dense_dot(left, right)
 
     dot = __dot__
 
     def __matmul__(left, right):
-        return at.math.matmul(left, right)
+        return pt.math.matmul(left, right)
 
     def __rmatmul__(right, left):
-        return at.math.matmul(left, right)
+        return pt.math.matmul(left, right)
 
     def sum(self, axis=None, dtype=None, keepdims=False, acc_dtype=None):
         """See :func:`pytensor.tensor.math.sum`."""
-        return at.math.sum(
+        return pt.math.sum(
             self, axis=axis, dtype=dtype, keepdims=keepdims, acc_dtype=acc_dtype
         )
 
     def prod(self, axis=None, dtype=None, keepdims=False, acc_dtype=None):
         """See :func:`pytensor.tensor.math.prod`."""
-        return at.math.prod(
+        return pt.math.prod(
             self, axis=axis, dtype=dtype, keepdims=keepdims, acc_dtype=acc_dtype
         )
 
@@ -677,60 +677,60 @@ class _tensor_py_operators:
         if np.isinf(L):
             raise NotImplementedError()
         # optimizations will/should catch cases like L=1, L=2
-        y = at.math.pow(
-            at.math.pow(at.math.abs(self), L).sum(axis=axis),
+        y = pt.math.pow(
+            pt.math.pow(pt.math.abs(self), L).sum(axis=axis),
             1.0 / L,
         )
         if keepdims:
-            return at.math.makeKeepDims(self, y, axis)
+            return pt.math.makeKeepDims(self, y, axis)
         else:
             return y
 
     def mean(self, axis=None, dtype=None, keepdims=False, acc_dtype=None):
         """See :func:`pytensor.tensor.math.mean`."""
-        return at.math.mean(
+        return pt.math.mean(
             self, axis=axis, dtype=dtype, keepdims=keepdims, acc_dtype=acc_dtype
         )
 
     def var(self, axis=None, ddof=0, keepdims=False, corrected=False):
         """See :func:`pytensor.tensor.math.var`."""
-        return at.math.var(
+        return pt.math.var(
             self, axis=axis, ddof=ddof, keepdims=keepdims, corrected=corrected
         )
 
     def std(self, axis=None, ddof=0, keepdims=False, corrected=False):
         """See :func:`pytensor.tensor.math.std`."""
-        return at.math.std(
+        return pt.math.std(
             self, axis=axis, ddof=ddof, keepdims=keepdims, corrected=corrected
         )
 
     def min(self, axis=None, keepdims=False):
         """See :func:`pytensor.tensor.math.min`."""
-        return at.math.min(self, axis, keepdims=keepdims)
+        return pt.math.min(self, axis, keepdims=keepdims)
 
     def max(self, axis=None, keepdims=False):
         """See :func:`pytensor.tensor.math.max`."""
-        return at.math.max(self, axis, keepdims=keepdims)
+        return pt.math.max(self, axis, keepdims=keepdims)
 
     def argmin(self, axis=None, keepdims=False):
         """See :func:`pytensor.tensor.math.argmin`."""
-        return at.math.argmin(self, axis, keepdims=keepdims)
+        return pt.math.argmin(self, axis, keepdims=keepdims)
 
     def argmax(self, axis=None, keepdims=False):
         """See :func:`pytensor.tensor.math.argmax`."""
-        return at.math.argmax(self, axis, keepdims=keepdims)
+        return pt.math.argmax(self, axis, keepdims=keepdims)
 
     def nonzero(self, return_matrix=False):
         """See :func:`pytensor.tensor.basic.nonzero`."""
-        return at.nonzero(self, return_matrix=return_matrix)
+        return pt.nonzero(self, return_matrix=return_matrix)
 
     def nonzero_values(self):
         """See :func:`pytensor.tensor.basic.nonzero_values`."""
-        return at.nonzero_values(self)
+        return pt.nonzero_values(self)
 
     def sort(self, axis=-1, kind="quicksort", order=None):
         """See :func:`pytensor.tensor.sort.sort`."""
-        return at.sort(self, axis, kind, order)
+        return pt.sort(self, axis, kind, order)
 
     def argsort(self, axis=-1, kind="quicksort", order=None):
         """See :func:`pytensor.tensor.sort.argsort`."""
@@ -740,50 +740,50 @@ class _tensor_py_operators:
 
     def clip(self, a_min, a_max):
         "See :func:`pytensor.tensor.math.clip`."
-        return at.math.clip(self, a_min, a_max)
+        return pt.math.clip(self, a_min, a_max)
 
     def conj(self):
         """See :func:`pytensor.tensor.math.conj`."""
-        return at.math.conj(self)
+        return pt.math.conj(self)
 
     conjugate = conj
 
     def repeat(self, repeats, axis=None):
         """See :func:`pytensor.tensor.basic.repeat`."""
-        return at.extra_ops.repeat(self, repeats, axis)
+        return pt.extra_ops.repeat(self, repeats, axis)
 
     def round(self, mode=None):
         """See :func:`pytensor.tensor.math.round`."""
-        return at.math.round(self, mode)
+        return pt.math.round(self, mode)
 
     def trace(self):
-        return at.linalg.trace(self)
+        return pt.linalg.trace(self)
 
     # This value is set so that PyTensor arrays will trump NumPy operators.
     __array_priority__ = 1000
 
     def get_underlying_scalar_constant(self):
-        return at.basic.get_underlying_scalar_constant_value(self)
+        return pt.basic.get_underlying_scalar_constant_value(self)
 
     def zeros_like(model, dtype=None):
-        return at.basic.zeros_like(model, dtype=dtype)
+        return pt.basic.zeros_like(model, dtype=dtype)
 
     def ones_like(model, dtype=None):
-        return at.basic.ones_like(model, dtype=dtype)
+        return pt.basic.ones_like(model, dtype=dtype)
 
     def cumsum(self, axis=None):
-        return at.extra_ops.cumsum(self, axis)
+        return pt.extra_ops.cumsum(self, axis)
 
     def cumprod(self, axis=None):
-        return at.extra_ops.cumprod(self, axis)
+        return pt.extra_ops.cumprod(self, axis)
 
     def searchsorted(self, v, side="left", sorter=None):
-        return at.extra_ops.searchsorted(self, v, side, sorter)
+        return pt.extra_ops.searchsorted(self, v, side, sorter)
 
     def ptp(self, axis=None):
         """See :func:`pytensor.tensor.math.ptp`."""
 
-        return at.math.ptp(self, axis)
+        return pt.math.ptp(self, axis)
 
     def swapaxes(self, axis1, axis2):
         """See :func:`pytensor.tensor.basic.swapaxes`.
@@ -792,11 +792,11 @@ class _tensor_py_operators:
         will be returned.
 
         """
-        return at.basic.swapaxes(self, axis1, axis2)
+        return pt.basic.swapaxes(self, axis1, axis2)
 
     def fill(self, value):
         """Fill inputted tensor with the assigned value."""
-        return at.basic.fill(self, value)
+        return pt.basic.fill(self, value)
 
     def choose(self, choices, mode="raise"):
         """
@@ -804,7 +804,7 @@ class _tensor_py_operators:
         from.
 
         """
-        return at.basic.choose(self, choices, mode="raise")
+        return pt.basic.choose(self, choices, mode="raise")
 
     def squeeze(self, axis=None):
         """
@@ -814,11 +814,11 @@ class _tensor_py_operators:
         removed. This is always `x` itself or a view into `x`.
 
         """
-        return at.extra_ops.squeeze(self, axis=axis)
+        return pt.extra_ops.squeeze(self, axis=axis)
 
     def compress(self, a, axis=None):
         """Return selected slices only."""
-        return at.extra_ops.compress(self, a, axis=axis)
+        return pt.extra_ops.compress(self, a, axis=axis)
 
     def set(self, idx, y, **kwargs):
         """Return a copy of self with the indexed values set to y.
@@ -833,7 +833,7 @@ class _tensor_py_operators:
         >>> out = x.set(1, 2)
         >>> out.eval()  # array([1., 2., 1.])
         """
-        return at.subtensor.set_subtensor(self[idx], y, **kwargs)
+        return pt.subtensor.set_subtensor(self[idx], y, **kwargs)
 
     def inc(self, idx, y, **kwargs):
         """Return a copy of self with the indexed values incremented by y.
@@ -849,7 +849,7 @@ class _tensor_py_operators:
         >>> out = x.inc(1, 2)
         >>> out.eval()  # array([1., 3., 1.])
         """
-        return at.inc_subtensor(self[idx], y, **kwargs)
+        return pt.inc_subtensor(self[idx], y, **kwargs)
 
 
 class TensorVariable(
@@ -1068,7 +1068,7 @@ class TensorConstant(TensorVariable, Constant[_TensorTypeType]):
         # numpy.ndarray, and python type.
         if isinstance(other, (np.ndarray, int, float)):
             # Make a TensorConstant to be able to compare
-            other = at.basic.constant(other)
+            other = pt.basic.constant(other)
         return (
             isinstance(other, TensorConstant) and self.signature() == other.signature()
         )
