@@ -1,6 +1,6 @@
 import numpy as np
 
-import pytensor.tensor as at
+import pytensor.tensor as pt
 from pytensor.compile.debugmode import _lessbroken_deepcopy
 from pytensor.configdefaults import config
 from pytensor.graph.basic import Apply, Constant, Variable
@@ -78,7 +78,7 @@ class GetItem(COp):
                 index = Constant(SliceType(), index)
                 return Apply(self, [x, index], [x.type()])
             else:
-                index = at.constant(index, ndim=0, dtype="int64")
+                index = pt.constant(index, ndim=0, dtype="int64")
                 return Apply(self, [x, index], [x.ttype()])
         if isinstance(index.type, SliceType):
             return Apply(self, [x, index], [x.type()])
@@ -323,7 +323,7 @@ class Insert(COp):
         assert isinstance(x.type, TypedListType)
         assert x.ttype == toInsert.type
         if not isinstance(index, Variable):
-            index = at.constant(index, ndim=0, dtype="int64")
+            index = pt.constant(index, ndim=0, dtype="int64")
         else:
             assert index.dtype == "int64"
             assert isinstance(index, TensorVariable) and index.ndim == 0
@@ -650,7 +650,7 @@ class MakeList(Op):
         a2 = []
         for elem in a:
             if not isinstance(elem, Variable):
-                elem = at.as_tensor_variable(elem)
+                elem = pt.as_tensor_variable(elem)
             a2.append(elem)
         if not all(a2[0].type.is_super(elem.type) for elem in a2):
             raise TypeError("MakeList need all input variable to be of the same type.")
